/*
 * Copyright 2011 Timothy Sparg
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kilnhg.timsparg.juniorkilndomain;

import java.util.List;

/**
 * This record contains the keys:
 *
 *    ixChangeset: a unique changeset identifier
 *    rev: the changeset's revision
 *    sAuthor: the author's name, as configured in the author's .hgrc file
 *    sDescription: the changeset message
 *    dt: the changeset's date
 *    revParent1: the changeset's parent revision (null if the changeset is a tail changeset)
 *    revParent2: the changeset's second parent revision (null if there is none; non-null if the changeset is a merge)
 *    diffs: a list of diff records, one per file modified
 * 
 * @author Tim Sparg
 */
public class Changeset {

    private int ixChangeset;
    private String rev;
    private String sAuthor;
    private String sDescription;
    private String dt;
    private String revParent1;
    private String revParent2;
    private List<Diff> diffs;

    /**
     * 
     * @return a list of diff records, one per file modified
     */
    public List<Diff> getDiffs() {
        return diffs;
    }

    /**
     * Sets a list of diff records
     * @param diffs 
     */
    public void setDiffs(List<Diff> diffs) {
        this.diffs = diffs;
    }

    /**
     * 
     * @return  the changeset's date as a string
     */
    public String getDt() {
        return dt;
    }

    /**
     * Sets the changeset's date as a String
     * @param dt 
     */
    public void setDt(String dt) {
        this.dt = dt;
    }

    /**
     * 
     * @return a unique changeset identifier
     */
    public int getIxChangeset() {
        return ixChangeset;
    }

    /**
     * Set a unique changeset identifier
     */
    public void setIxChangeset(int ixChangeset) {
        this.ixChangeset = ixChangeset;
    }

    /**
     * 
     * @return the changeset's revision
     */
    public String getRev() {
        return rev;
    }

    /**
     * Set the changeset's revision
     * @param rev 
     */
    public void setRev(String rev) {
        this.rev = rev;
    }

    /**
     * the changeset's parent revision (null if the changeset is a tail changeset)
     * 
     * @return the changeset's parent revision 
     */
    public String getRevParent1() {
        return revParent1;
    }

    /**
     *  the changeset's parent revision 
     * 
     * @param revParent1 
     */
    public void setRevParent1(String revParent1) {
        this.revParent1 = revParent1;
    }

    /**
     * the changeset's second parent revision 
     * (null if there is none; non-null if the changeset is a merge)
     * @return the changeset's second parent revision 
     */
    public String getRevParent2() {
        return revParent2;
    }

    /**
     * Sets the changeset's second parent revision.
     * 
     * @param revParent2 
     */
    public void setRevParent2(String revParent2) {
        this.revParent2 = revParent2;
    }

    /**
     * the author's name, as configured in the author's .hgrc file
     * 
     * @return the author's name
     */
    public String getsAuthor() {
        return sAuthor;
    }

    /**
     * Sets the author's name
     * @param sAuthor 
     */
    public void setsAuthor(String sAuthor) {
        this.sAuthor = sAuthor;
    }

    /**
     * 
     * @return the changeset message
     */
    public String getsDescription() {
        return sDescription;
    }

    /**
     * Sets the changeset message
     * @param sDescription 
     */
    public void setsDescription(String sDescription) {
        this.sDescription = sDescription;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 71 * hash + this.ixChangeset;
        hash = 71 * hash + (this.rev != null ? this.rev.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Changeset other = (Changeset) obj;
        if (this.ixChangeset != other.ixChangeset) {
            return false;
        }
        if ((this.rev == null) ? (other.rev != null) : !this.rev.equals(other.rev)) {
            return false;
        }
        if ((this.sAuthor == null) ? (other.sAuthor != null) : !this.sAuthor.equals(other.sAuthor)) {
            return false;
        }
        if ((this.sDescription == null) ? (other.sDescription != null) : !this.sDescription.equals(other.sDescription)) {
            return false;
        }
        if ((this.dt == null) ? (other.dt != null) : !this.dt.equals(other.dt)) {
            return false;
        }
        if ((this.revParent1 == null) ? (other.revParent1 != null) : !this.revParent1.equals(other.revParent1)) {
            return false;
        }
        if ((this.revParent2 == null) ? (other.revParent2 != null) : !this.revParent2.equals(other.revParent2)) {
            return false;
        }
        if (this.diffs != other.diffs && (this.diffs == null || !this.diffs.equals(other.diffs))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "Changeset{" + "ixChangeset=" + ixChangeset + ", rev=" + rev + ", sAuthor=" + sAuthor + ", sDescription=" + sDescription + ", dt=" + dt + ", revParent1=" + revParent1 + ", revParent2=" + revParent2 + ", diffs=" + diffs + '}';
    }
}
