/*
 * Copyright 2011 Timothy Sparg
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kilnhg.timsparg.juniorkilndomain;

import java.util.List;

/**
 *This record contains the keys:
 *
 *    ixRepo: a unique repository identifier
 *    ixRepoGroup: the repository group the repository belongs to
 *    ixParent: the repository this repository was branched from; null if this repository was not branched from any repository
 *    fCentral: returns true if the repository is central, false otherwise
 *    sSlug: a unique repository URL slug
 *    sGroupSlug: the repository's repository group unique URL slug
 *    sProjectSlug: the repository's project unique URL slug
 *    sName: the repository name
 *    sDescription: the repository description
 *    sStatus: the status of the repository in the backend (one of "error", "new", "good", "conflicted", or "deleted")
 *    bytesSize: the size of the repository in bytes, may be null if the Kiln backend has yet to tally this information
 *    personCreator: the creator's person record
 *    permissionDefault: the default repository permission
 *    repoBranches: a list of repository records that are branches of this repository; the list is empty if this repository is not a central repository (only central repositories may have branch repositories, same as the website user interface)
 *
 * @author Tim Sparg
 */
public class Repository {

    private int ixRepo;
    private int ixRepoGroup;
    private int ixParent;
    private boolean fcentral;
    private String sSlug;
    private String sGroupSlug;
    private String sProjectSlug;
    private String sName;
    private String sDescription;
    private String sStatus;
    private Integer bytesSize;
    private Person personCreator;
    private List<Repository> repoBranches;

    /**
     * Needs to be of type Integer as Kiln may return null.
     * 
     * @return the size of the repository in bytes, may be null if the Kiln 
     * backend has yet to tally this information
     */
    public Integer getBytesSize() {
        return bytesSize;
    }

    /**
     * Sets the size of the repository in bytes
     * 
     * @param bytesSize 
     */
    public void setBytesSize(Integer bytesSize) {
        this.bytesSize = bytesSize;
    }

    /**
     * 
     * @return true if the repository is central, false otherwise
     */
    public boolean isFcentral() {
        return fcentral;
    }

    /**
     * True sets the repository to Central
     * @param fcentral 
     */
    public void setFcentral(boolean fcentral) {
        this.fcentral = fcentral;
    }

    /**
     * 
     * @return the repository this repository was branched from; null if this 
     * repository was not branched from any repository
     */
    public int getIxParent() {
        return ixParent;
    }

    /**
     * Sets the repository this repository was branched from
     * @param ixParent 
     */
    public void setIxParent(int ixParent) {
        this.ixParent = ixParent;
    }

    /**
     * 
     * @return a unique repository identifier
     */
    public int getIxRepo() {
        return ixRepo;
    }

    /**
     * Sets a unique repository identifier
     * @param ixRepo 
     */
    public void setIxRepo(int ixRepo) {
        this.ixRepo = ixRepo;
    }

    /**
     * 
     * @return the repository group the repository belongs to
     */
    public int getIxRepoGroup() {
        return ixRepoGroup;
    }

    /**
     * Sets the repository group the repository belongs to
     * @param ixRepoGroup 
     */
    public void setIxRepoGroup(int ixRepoGroup) {
        this.ixRepoGroup = ixRepoGroup;
    }

    /**
     * 
     * @return the creator's person record
     */
    public Person getPersonCreator() {
        return personCreator;
    }

    /**
     * Sets the creator's person record
     * @param personCreator 
     */
    public void setPersonCreator(Person personCreator) {
        this.personCreator = personCreator;
    }

    /**
     * a list of repository records that are branches of this repository; 
     * the list is empty if this repository is not a central repository 
     * (only central repositories may have branch repositories, same as the 
     * website user interface)
     * 
     * @return a list of repository records that are branches of this repository
     */
    public List<Repository> getRepoBranches() {
        return repoBranches;
    }

    /**
     * Sets a list of repository records that are branches of this repository
     * @param repoBranches 
     */
    public void setRepoBranches(List<Repository> repoBranches) {
        this.repoBranches = repoBranches;
    }

    /**
     * 
     * @return the repository description
     */
    public String getsDescription() {
        return sDescription;
    }

    /**
     * Sets the repository description
     * @param sDescription 
     */
    public void setsDescription(String sDescription) {
        this.sDescription = sDescription;
    }

    /**
     * 
     * @return the repository's repository group unique URL slug
     */
    public String getsGroupSlug() {
        return sGroupSlug;
    }

    /**
     * Sets the repository's repository group unique URL slug
     * 
     * @param sGroupSlug 
     */
    public void setsGroupSlug(String sGroupSlug) {
        this.sGroupSlug = sGroupSlug;
    }

    /**
     * 
     * @return the repository name
     */
    public String getsName() {
        return sName;
    }

    /**
     * Sets the repository name
     * @param sName 
     */
    public void setsName(String sName) {
        this.sName = sName;
    }

    /**
     * 
     * @return the repository's project unique URL slug
     */
    public String getsProjectSlug() {
        return sProjectSlug;
    }

    /**
     * Sets the repository's project unique URL slug
     * 
     * @param sProjectSlug 
     */
    public void setsProjectSlug(String sProjectSlug) {
        this.sProjectSlug = sProjectSlug;
    }

    /**
     * 
     * @return a unique repository URL slug
     */
    public String getsSlug() {
        return sSlug;
    }

    /**
     * Sets a unique repository URL slug
     * 
     * @param sSlug 
     */
    public void setsSlug(String sSlug) {
        this.sSlug = sSlug;
    }

    /**
     * the status of the repository in the backend 
     * (one of "error", "new", "good", "conflicted", or "deleted")
     
     * @return the status of the repository in the backend 
     */
    public String getsStatus() {
        return sStatus;
    }

    /**
     * Sets the status of the repository in the backend 
     * @param sStatus 
     */
    public void setsStatus(String sStatus) {
        this.sStatus = sStatus;
    }

    @Override
    public String toString() {
        return "Repository{" + "ixRepo=" + ixRepo + ";ixRepoGroup="
                + ixRepoGroup + ";ixParent=" + ixParent + ";fcentral="
                + fcentral + ";sSlug=" + sSlug + ";sGroupSlug=" + sGroupSlug
                + ";sProjectSlug=" + sProjectSlug + ";sName=" + sName
                + ";sDescription=" + sDescription + ";sStatus=" + sStatus
                + ";bytesSize=" + bytesSize + ";personCreator=" + personCreator
                + ";repoBranches=" + repoBranches + '}';
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Repository other = (Repository) obj;
        if (this.ixRepo != other.ixRepo) {
            return false;
        }
        if (this.ixRepoGroup != other.ixRepoGroup) {
            return false;
        }
        if (this.ixParent != other.ixParent) {
            return false;
        }
        if (this.fcentral != other.fcentral) {
            return false;
        }
        if ((this.sSlug == null) ? (other.sSlug != null) : !this.sSlug.equals(other.sSlug)) {
            return false;
        }
        if ((this.sGroupSlug == null) ? (other.sGroupSlug != null) : !this.sGroupSlug.equals(other.sGroupSlug)) {
            return false;
        }
        if ((this.sProjectSlug == null) ? (other.sProjectSlug != null) : !this.sProjectSlug.equals(other.sProjectSlug)) {
            return false;
        }
        if ((this.sName == null) ? (other.sName != null) : !this.sName.equals(other.sName)) {
            return false;
        }
        if ((this.sDescription == null) ? (other.sDescription != null) : !this.sDescription.equals(other.sDescription)) {
            return false;
        }
        if ((this.sStatus == null) ? (other.sStatus != null) : !this.sStatus.equals(other.sStatus)) {
            return false;
        }
        if (this.bytesSize != other.bytesSize && (this.bytesSize == null || !this.bytesSize.equals(other.bytesSize))) {
            return false;
        }
        if (this.personCreator != other.personCreator && (this.personCreator == null || !this.personCreator.equals(other.personCreator))) {
            return false;
        }
        if (this.repoBranches != other.repoBranches && (this.repoBranches == null || !this.repoBranches.equals(other.repoBranches))) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 97 * hash + this.ixRepo;
        hash = 97 * hash + this.ixRepoGroup;
        hash = 97 * hash + this.ixParent;
        return hash;
    }
}
